@@ -64,7 +64,9 @@ test_that("We can set and get resource parameters", {
 })
 
 test_that("Comment works on resource_rate", {
-  params <- NS_params
+  # We need to re-set the resource becaue different architectures give
+  # different results
+  params <- setResource(NS_params)
   # if no comment, it is set automatically
   resource_rate <- params@rr_pp
   params <- setResource(params, resource_rate = resource_rate)
